prefix="/usr"
datadir="/usr/share"
localedir=datadir+"/locale"
pkgdatadir="/usr/share/alacarte"
libdir="/usr/lib"
libexecdir="/usr/libexec"
PACKAGE="alacarte"
VERSION="3.54.0"
GETTEXT_PACKAGE="alacarte"
